$(document).ready(function () {

    var table = $('#myTable').DataTable({
        "scrollX": true,
        "order": [],
        "columns": [
            { "data": "reference_no" },
            { "data": "store_from" },
            { "data": "store_to" },
            { "data": "date" },
            { "data": "edit", className: "edit" },
            { "data": "view", className: "view" },
            { "data": "approve", className: "approve" },
            { "data": "delete", className: "delete" },
        ],
        columnDefs: [
            { width: 200, targets: 0 },
            { width: 200, targets: 3 },
            { width: 30, targets: 4 },
            { width: 30, targets: 5 },
            { width: 30, targets: 6 },
        ],
    });
    //table.column(4).visible(false);
    table.column(7).visible(false);

    allGoodsTransfer();

});


function allGoodsTransfer() {
    $.ajax({
        type: "GET",
        url: "/sc/GoodsTransferListController/allGoodsTransfer",
        processData: false,
        contentType: false,
        cache: false,
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            if (response.data.success) {
                var data = [];

                for (i = 0; i < response.data.result.length; i++) {
                    var id = response.data.result[i]['internal_id'];
                    var reference_no = response.data.result[i]['external_id'];
                    var store_from = response.data.result[i]['store_from'];
                    var store_to = response.data.result[i]['store_to'];
                    var date = response.data.result[i]['trans_date'];
                    var status = response.data.result[i]['status'];
                    var string_id = "'" + id + "'";

                    var approve_btn = '<i class="fa fa-times" aria-hidden="true"></i>';
                    var disabled = "";
                    if (status == 1) {
                        approve_btn = '<i class="fa fa-check" aria-hidden="true"></i>';
                        disabled = "disabled";
                    }

                    data.push({
                        "reference_no": reference_no,
                        "store_from": store_from,
                        "store_to": store_to,
                        "date": date,
                        "edit": '<button class="btn btn-primary" onclick="edit(' + string_id + ')"><i class="fa fa-pencil-square-o" aria-hidden="true"></i></button>',
                        "view": '<button class="btn btn-success" onclick="view(' + string_id + ')"><i class="fa fa-eye" aria-hidden="true"></i></button>',
                        "approve": '<button id="approve' + id + '" class="btn btn-success" onclick="approve_confirmation(' + string_id + ')" '+disabled+'>'+approve_btn+'</button>',
                        "delete": '<button class="btn btn-danger" onclick="delete_confirmation(' + string_id + ')" '+disabled+'><i class="fa fa-trash" aria-hidden="true"></i></button>'
                    });
                }

                var table = $('#myTable').DataTable();
                table.clear();
                table.rows.add(data).draw();
            }
        },

        error: function (error) {
            console.log(error);


        },
        complete: function () {

        }

    });
}


function edit(id) {
    location.href = "/sc/goods_transfer?id=" + id + "&action=edit";
}



function view(id) {
    location.href = "/sc/goods_transfer?id=" + id + "&action=view";
}



function delete_confirmation(id) {
    swal({
        title: "Are you sure want delete?",
        //text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: {
            yes: {
                text: "Yes",
                value: true,
                className: 'btn btn-danger',
            },
            no: {
                text: "No",
                value: false,
                className: 'btn btn-primary',
            }
        },

    })
        .then((willDelete) => {
            if (willDelete) {
                _delete(id);
            }
        });

}




function approve_confirmation(id) {
    swal({
        title: "Are you sure want to approve?",
        //text: "Once deleted, you will not be able to recover this record!",
        icon: "warning",
        buttons: {
            yes: {
                text: "Yes",
                value: true,
                className: 'btn btn-danger',
            },
            no: {
                text: "No",
                value: false,
                className: 'btn btn-primary',
            }
        },

    })
        .then((willDelete) => {
            if (willDelete) {
                approve(id);
            }
        });

}


function _delete(id){

    $.ajax({
        type: 'DELETE',
        url: '/sc/GoodsTransferController/deleteGoodsTransfer/' + id,
        headers: {
            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
        },
        timeout: 800000,
        beforeSend: function () {

        },
        success: function (response) {
            console.log(response);
            if (response.data.success) {
                showSuccessMessage("Data has been deleted successfully...")
                allGoodsTransfer();
            } else {
                showErrorMessage();
            }
        },
        error: function (error) {
            console.log(error);
            showErrorMessage();
        },
        complete: function () {

        }

    }); 
}




function approve(id) {
    $.ajax({
        type: "PUT",
        url: '/sc/GoodsTransferController/approve/' + id,
        data: {
            status: 1,
        },
        headers: {
            'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
        },
        timeout: 800000,
        beforeSend: function () {
            document.getElementById('approve'+id).innerHTML = '<i class="fa fa-circle-o-notch fa-spin"></i>';
        },
        success: function (response) {
            console.log(response);
            toastr.success(response.data.result.message);
            $('#approve' + id).html(response.data.result.icon);
            allGoodsTransfer();
        },
        error: function (error) {
            console.log(error);
            toastr.error('Something went wrong');
        },
        complete: function () {
           // document.getElementById('approve'+id).innerHTML = '<i class="fa fa-times" aria-hidden="true"></i>';
        }

    });
}


/**
* showSuccessMessage
* This function is used to show success message.
* @param message This is the paramter to require message content
*/
function showSuccessMessage(message) {
    toastr.success(message);
}


/**
* showWarningMessage
* This function is used to show warning message.
* @param message This is the paramter to require message content
*/
function showWarningMessage(message) {
    toastr.warning(message);
}



/**
* showErrorMessage
* This function is used to show error message.
* @param message This is the paramter to require message content
*/
function showErrorMessage() {
    toastr.error('Something went wrong');
}



